@@ -1,14 +1,12 @@
-import time
-from pathlib import Path
 from threading import Lock
-from threading import Thread
 
 from je_editor.utils.exception.exceptions import JEditorSaveFileException
+from je_editor.utils.logging.loggin_instance import jeditor_logger
 
 
-def write_file(file, content):
+def write_file(file_path: str, content: str) -> None:
     """
-    :param file: file we want to write
+    :param file_path: file we want to write
     :param content: content write in file
     try
         lock thread
@@ -17,15 +15,17 @@ def write_file(file, content):
     finally
         release lock
     """
+    jeditor_logger.info("save_file.py write_file "
+                        f"file_path: {file_path} "
+                        f"content: {content}")
     lock = Lock()
     content = str(content)
     try:
         lock.acquire()
-        if file != "" and file is not None:
-            with open(file, "w+") as file_to_write:
+        if file_path != "" and file_path is not None:
+            with open(file_path, "w+", encoding="utf-8") as file_to_write:
                 file_to_write.write(content)
     except JEditorSaveFileException:
         raise JEditorSaveFileException
     finally:
         lock.release()
-
